pipe<NewRunOutput extends Object?, NewCallOptions extends RunnableOptions> method
RunnableSequence<PromptValue, NewRunOutput>
pipe<NewRunOutput extends Object?, NewCallOptions extends RunnableOptions>(
- Runnable<
ChatResult, NewCallOptions, NewRunOutput> next
inherited
Pipes the output of this Runnable into another Runnable using a
RunnableSequence.
A RunnableSequence allows you to run multiple Runnable objects
sequentially, passing the output of the previous Runnable to the next one.
next- theRunnableto pipe the output into.
Implementation
RunnableSequence<RunInput, NewRunOutput> pipe<
NewRunOutput extends Object?,
NewCallOptions extends RunnableOptions
>(final Runnable<RunOutput, NewCallOptions, NewRunOutput> next) {
return RunnableSequence<RunInput, NewRunOutput>(first: this, last: next);
}